@@ -1,6 +1,6 @@
 ;;; foils.el - Special code for FoilTeX.
 
-;; $Id: foils.el,v 1.1.1.1 1998/01/14 06:45:46 steve Exp $
+;; $Id: foils.el,v 1.2 2000/01/19 12:30:57 andreasj Exp $
 
 ;;; Code:
 
@@ -33,7 +33,7 @@
       (insert TeX-esc "date" TeX-grop
 	      (format "%d-%02d-%02d" year month day)
 	      TeX-grcl "\n")
-      (insert "" TeX-esc "\nMyLogo" TeX-grop TeX-grcl "\n")
+      (insert "" TeX-esc "MyLogo" TeX-grop TeX-grcl "\n")
       (insert "%" TeX-esc "Restriction" TeX-grop TeX-grcl "\n")
       (insert "%" TeX-esc "rightfooter" TeX-grop TeX-grcl "\n")
       (insert "%" TeX-esc "leftheader" TeX-grop TeX-grcl "\n")
